Crate injoint_macros

Crate injoint_macros 

Attribute Macros

reducer_actions
This macro is used to annotate a struct as a reducer and generate the necessary code for the reducer actions.
reducer_struct
This macro is used to annotate a struct as a reducer.

Derive Macros

Broadcastable
This macro derives the Broadcastable trait for a struct.