Attribute Macros
- reducer_
actions - This macro is used to annotate a struct as a reducer and generate the necessary code for the reducer actions.
- reducer_
struct - This macro is used to annotate a struct as a reducer.
Derive Macros
- Broadcastable
- This macro derives the
Broadcastabletrait for a struct.